@@ -2,9 +2,10 @@
 from __future__ import absolute_import, unicode_literals
 import os
 
+from badwolf.utils import run_command
 from badwolf.lint import Problem
 from badwolf.lint.linters import Linter
-from badwolf.lint.utils import in_path, npm_exists, run_command, parse_checkstyle
+from badwolf.lint.utils import in_path, npm_exists, parse_checkstyle
 
 
 class CSSLinter(Linter):
@@ -14,6 +15,12 @@ class CSSLinter(Linter):
     def is_usable(self):
         return in_path('csslint') or npm_exists('csslint', self.working_dir)
 
+    def match_file(self, filename):
+        # 过滤掉压缩过的 CSS 文件
+        if filename.lower().endswith('.min.css'):
+            return False
+        return super(CSSLinter, self).match_file(filename)
+
     def lint_files(self, files):
         command = self.create_command(files)
         _, output = run_command(command, cwd=self.working_dir)
