@@ -1,10 +1,12 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import, unicode_literals
+
 import os
 
+from badwolf.utils import run_command
 from badwolf.lint import Problem
 from badwolf.lint.linters import Linter
-from badwolf.lint.utils import in_path, npm_exists, run_command, parse_checkstyle
+from badwolf.lint.utils import in_path, npm_exists, parse_checkstyle
 
 
 class SassLinter(Linter):
