@@ -1,8 +1,10 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import, unicode_literals
+
+from badwolf.utils import run_command
 from badwolf.lint import Problem
 from badwolf.lint.linters import Linter
-from badwolf.lint.utils import in_path, run_command, parse_checkstyle
+from badwolf.lint.utils import in_path, parse_checkstyle
 
 
 class ShellCheckLinter(Linter):
