@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import, unicode_literals
+
 import os
 import json
 
+from badwolf.utils import run_command
 from badwolf.lint import Problem
 from badwolf.lint.linters import Linter
-from badwolf.lint.utils import in_path, npm_exists, run_command
+from badwolf.lint.utils import in_path, npm_exists
 
 
 class StyleLinter(Linter):
@@ -15,6 +17,12 @@ class StyleLinter(Linter):
     def is_usable(self):
         return in_path('stylelint') or npm_exists('stylelint', self.working_dir)
 
+    def match_file(self, filename):
+        # 过滤掉压缩过的 CSS 文件
+        if filename.lower().endswith('.min.css'):
+            return False
+        return super(StyleLinter, self).match_file(filename)
+
     def lint_files(self, files):
         command = self.create_command(files)
         _, output = run_command(command, cwd=self.working_dir)
